# Swissroll

[![codecov](https://codecov.io/gh/tirthasheshpatel/swissroll/branch/master/graph/badge.svg)](https://codecov.io/gh/tirthasheshpatel/swissroll)
[![build status](https://travis-ci.com/tirthasheshpatel/swissroll.svg?branch=master)](https://travis-ci.com/tirthasheshpatel/swissroll)

This is a higher level API made with scipy and numpy for working with probability distributions. It's a very simple package and can be used for teaching and demonstrating purposes. Do not use for anything **serious**!

### Installation

`pip install swissroll`

### Usage

See the following notebooks to understand usage of the API:
 - [Swissroll Tutorial](tasty_swissroll.ipynb)

### Contributing

Anyone can contribute by adding a new feature or fixing the current ones. Every contribution is welcome and appreciated.

